@@ -134,7 +134,7 @@ int ext_htm_runTopLevelTasks(ext_htm_manager_t restrict manager, ext_htm_topLeve
     return result;
   }
   
-  // ext_printf("running top %lu level tasks\n", numTasks);
+  // ext_printf("running top %lu level tasks without output\n", numTasks);
   
   for (taskId = 0; taskId < numTasks; ++taskId) {
     while (stackIsEmpty(&manager->availableThreadStack)) waitOnCondition(manager->taskDone, manager->mutex);
@@ -220,7 +220,7 @@ int ext_htm_runTopLevelTasksWithOutput(ext_htm_manager_t restrict manager, ext_h
   wakeTime.tv_sec += outputDelay->tv_sec;
   wakeTime.tv_nsec += outputDelay->tv_nsec;
   
-  // ext_printf("running top %lu level tasks\n", numTasks);
+  // ext_printf("running top %lu level tasks with output\n", numTasks);
   
   for (taskId = 0; taskId < numTasks; ++taskId) {
     // while (stackIsEmpty(&manager->availableThreadStack)) waitOnCondition(manager->taskDone, manager->mutex);
@@ -236,6 +236,8 @@ int ext_htm_runTopLevelTasksWithOutput(ext_htm_manager_t restrict manager, ext_h
         getTime(&wakeTime);
         wakeTime.tv_sec += outputDelay->tv_sec;
         wakeTime.tv_nsec += outputDelay->tv_nsec;
+        wakeTime.tv_sec += wakeTime.tv_nsec / 1000000000;
+        wakeTime.tv_nsec %= 1000000000;
       }
     }
     
@@ -270,6 +272,8 @@ int ext_htm_runTopLevelTasksWithOutput(ext_htm_manager_t restrict manager, ext_h
       getTime(&wakeTime);
       wakeTime.tv_sec += outputDelay->tv_sec;
       wakeTime.tv_nsec += outputDelay->tv_nsec;
+      wakeTime.tv_sec += wakeTime.tv_nsec / 1000000000;
+      wakeTime.tv_nsec %= 1000000000;
     }
   }
   
@@ -371,7 +375,7 @@ static void* threadLoop(void* _thread)
   
   push(&manager->availableThreadStack, thread);
   manager->numThreadsAvailable++;
-   
+  
   signalCondition(manager->threadIsActive);
   
   while (true) {
@@ -682,6 +686,7 @@ static int initializeTopLevelTaskStatus(TopLevelTaskStatus* status)
   status->numThreads = 0;
   status->progress = TASK_BEFORE_START;
   status->numSubTaskPiecesInProgress = 0;
+  status->threadStack.first = NULL;
   
   int result = initializeCondition(status->taskDone);
   
